## **Transcription coregulator activity**

The activity unit for a transcription coregulator is:

* **MF:** a child of transcription coregulator activity ([GO:0003712](https://www.ebi.ac.uk/QuickGO/term/GO%3A0003712)):
  + transcription coactivator activity ([GO:0003713](https://www.ebi.ac.uk/QuickGO/term/GO%3A0003713))
  + transcription corepressor activity ([GO:0003714](https://www.ebi.ac.uk/QuickGO/term/GO%3A0003714))
* **Context:**
  + has input:the transcription factor regulated, when known.
  + **BP** in which this transcriptional event is involved
  + **CC:** this activity occurs in the [nucleus](https://www.ebi.ac.uk/QuickGO/term/GO%3A0005634).
* The causal relation between the transcription coregulator activity and the transcription factor activity unit is ‘directly positively regulates’ or 'directly negatively regulates.

* If the causal relation between the coregulator and the target gene regulated needs to be captured, the causal relation is: ‘indirectly positively regulates’ or 'indirectly negatively regulates’, since there are many steps between the regulation of transcription and the activity of the target protein.

### Example: [**GO:0003714 transcription corepressor activity**](http://noctua.geneontology.org/workbench/noctua-visual-pathway-editor/?model_id=gomodel%3A62900b6400001630)

![](data:image/png;base64...)

### Example: [**GO:0003713 transcription coactivator activity**](http://noctua.geneontology.org/workbench/noctua-visual-pathway-editor/?model_id=gomodel%3A63894f2500001048)

![](data:image/png;base64...)

### Example: [**GO:0003712 transcription coregulator activity**](http://noctua.geneontology.org/workbench/noctua-visual-pathway-editor/?model_id=gomodel%3A648d0dc100000022) (BMAL1 binds specifically DNA)

![](data:image/png;base64...)

### Example: [**Coregulator of an unknown transcription factor**](http://noctua.geneontology.org/workbench/noctua-visual-pathway-editor/?model_id=gomodel%3A62900b6400001630)

![](data:image/png;base64...)

# Review information

To be reviewed date:

Created by: Cristina Casals
